@@ -18,10 +18,11 @@
 
 import chess
 import signal
-import subprocess
 import logging
 import threading
 import concurrent.futures
+import os
+import sys
 
 try:
     import backport_collections as collections
@@ -33,6 +34,14 @@ try:
 except ImportError:
     import Queue as queue
 
+if os.name == "posix" and sys.version_info[0] < 3:
+    try:
+        import subprocess32 as subprocess
+    except ImportError:
+        import subprocess
+else:
+    import subprocess
+
 
 LOGGER = logging.getLogger(__name__)
 
@@ -594,7 +603,7 @@ class Engine(object):
             # non-UCI_Chess960 castling moves.
             try:
                 self.ponder = chess.Move.from_uci(tokens[2])
-                if self.ponder.from_square in (chess.E1, chess.E8) and self.ponder.to_square in (chess.C1, chess.C8, chess.G1, chess.G8):
+                if self.ponder.from_square in [chess.E1, chess.E8] and self.ponder.to_square in [chess.C1, chess.C8, chess.G1, chess.G8]:
                     # Make a copy of the board to avoid race conditions.
                     board = self.board.copy()
                     board.push(self.bestmove)
@@ -685,7 +694,7 @@ class Engine(object):
         # Find multipv parameter first.
         if "multipv" in arg:
             current_parameter = None
-            for token in arg.split():
+            for token in arg.split(" "):
                 if token == "string":
                     break
 
@@ -721,7 +730,7 @@ class Engine(object):
                 if current_parameter == "pv":
                     pv = []
 
-                if current_parameter in ("refutation", "pv", "currline"):
+                if current_parameter in ["refutation", "pv", "currline"]:
                     board = self.board.copy()
             elif current_parameter == "depth":
                 handle_integer_token(token, lambda handler, val: handler.depth(val))
@@ -740,7 +749,7 @@ class Engine(object):
                 # Ignore multipv. It was already parsed before anything else.
                 pass
             elif current_parameter == "score":
-                if token in ("cp", "mate"):
+                if token in ["cp", "mate"]:
                     score_kind = token
                 elif token == "lowerbound":
                     score_lowerbound = True
@@ -1328,7 +1337,7 @@ class Engine(object):
         return self.process.is_alive()
 
 
-def popen_engine(command, engine_cls=Engine):
+def popen_engine(command, engine_cls=Engine, _popen_lock=threading.Lock()):
     """
     Opens a local chess engine process.
 
@@ -1345,8 +1354,11 @@ def popen_engine(command, engine_cls=Engine):
     The input and input streams will be linebuffered and able both Windows
     and Unix newlines.
     """
-    process = PopenProcess(command)
-    return engine_cls(process)
+    # Work around possible race condition in Python 2 subprocess module,
+    # that can occur when concurrently opening processes.
+    with _popen_lock:
+        process = PopenProcess(command)
+        return engine_cls(process)
 
 
 def spur_spawn_engine(shell, command, engine_cls=Engine):
